

gm3dh5 Documentation
====================

A lightweighted interface for GrainMapper3D Results Files.


.. See: https://sphinx-design.readthedocs.io/en/furo-theme/grids.html
.. grid:: 3

   .. grid-item-card::
      :link: user/index
      :link-type: doc

      :octicon:`book;2em;sd-text-info` User Guide
      ^^^

      Read up on how to use gm3dh5.

      
   .. grid-item-card::
      :link: reference/index
      :link-type: doc

      :octicon:`code;2em;sd-text-info` API reference
      ^^^

      Reference guide how to use the API.

   .. grid-item-card::
      :link: examples/index
      :link-type: doc

      :octicon:`zap;2em;sd-text-info` Examples
      ^^^

      See examples how to use gm3dh5.


.. toctree::
   :hidden:
   :titlesonly:

   User Guide <user/index>
   API reference <reference/index>
   Examples <examples/index>


Installation
------------

gm3dh5 can be installed using pip by running the command:

.. code-block:: bash

   pip install gm3dh5

Alternative installation methods and further details are available in the
:doc:`installation guide <user/installation>`.

